/**
 * Returns a function for performing column and/or row-level security on an array of objects.
 *
 * @param data The original dataset (or function producing the dataset) to apply column and/or row-level security to.
 * @param security The predicate functions for column and row-level security.
 * @returns A function that can filter the original dataset given a provided context.
 */ function $149c1bd638913645$var$crls(data, security = ()=>true) {
    if (typeof data === "function") return async (context)=>{
        const rows = await data();
        return $149c1bd638913645$var$filterRows(rows, context, security);
    };
    return (context)=>$149c1bd638913645$var$filterRows(data, context, security);
}
function $149c1bd638913645$var$filterRows(rows, context, predicate) {
    let filtered = [], i = 0, l = rows.length;
    while(i < l){
        const row = rows[i];
        i++;
        // Evaluate the security predicate for the current row and provided context
        const security = predicate(row, context);
        // If the predicate returns false, exclude the row
        if (security === false) continue;
        // If the predicate returns true, include the row
        if (security === true) {
            filtered.push(row);
            continue;
        }
        let transformed = {}, keys = Object.keys(row), j = 0, m = keys.length;
        while(j < m){
            const col = keys[j], val = row[col];
            // Include the column if the CLS contains the column name
            if (security.has(col)) transformed[col] = val;
            j++;
        }
        // Include the transformed row
        filtered.push(transformed);
    }
    // Return the filtered dataset
    return filtered;
}
var $149c1bd638913645$export$2e2bcd8739ae039 = $149c1bd638913645$var$crls;


export {$149c1bd638913645$export$2e2bcd8739ae039 as default};
//# sourceMappingURL=module.js.map
